@@ -5,6 +5,7 @@
 #include <QStringList>
 #include <QSet>
 #include <QUrl>
+#include <QMap>
 #include <QProcess>
 
 class QIODevice;
@@ -20,12 +21,10 @@ public:
     virtual ~AUFiles();
 	virtual QUrl getUrl();
 	void initSettings();
-	virtual void updateSettingsFile();
-	virtual void checkDataStatus();
 	virtual void setInput(DownloadInput d);
 	virtual QString finishedDownload(QString channel, QIODevice *source);
-	virtual QStringList getChannelList();
 	void sendRecordMsg(QStringList data);
+	virtual bool isSingleXMLTVFile() { return false; }
 
 signals:
 
