@@ -105,6 +105,19 @@ DataDownloader::~DataDownloader()
 {
 }
 
+void DataDownloader::clearRegionData()
+{
+	QDir xmltvPath(QString(DATAPATH), QString("*.xml"));
+	foreach(QString filename, xmltvPath.entryList())
+	{
+		QString filepath = QString(DATAPATH)+filename;
+		QFile::remove(filepath);
+	}
+
+	QFile::remove(_settingsFile->fileName());
+	_channelDateMap.clear();
+}
+
 void DataDownloader::checkDataStatus()
 {
 	// IF (
@@ -124,6 +137,9 @@ void DataDownloader::checkDataStatus()
 	}
 	else
 	{
+		//qDebug() << "data for " << _requestChannel << " for date " << _requestDate << " does not exist";
+		//qDebug() << "max date in settings = " << _channelDateMap[_requestChannel].toList().first();
+
 		// download the requested channel for the requested date
 		_useLocal = false;
 
@@ -133,45 +149,42 @@ void DataDownloader::checkDataStatus()
 		{
 			QDir xmltvPath(QString(DATAPATH), QString("*.xml"));
 			foreach(QString filename, xmltvPath.entryList())
-				QFile::remove(filename);
-		}
-
-		// FOR SINGLE XMLTV file channels
-		// init the settings map with todays date for each channel
-		// this will later get updated as its read in updateSettings.
-		// we do this so that in case we download a channel with no data or no file then updateSettings wont be called
-		// and we will keep re-downloading all the files till we get a channel with data
-		// int his way atleast for the day we dont re-download on the same day if a channel doesnt have data so the user can keep trying
-		// to see other channels with the same data
-		if ( isSingleXMLTVFile() )
-		{
-			foreach(QString eachChannel, _channelCodeMap.keys())
 			{
-				_channelDateMap[eachChannel].clear();
-		   		_channelDateMap[eachChannel].insert(QDate::currentDate().toString("yyyyMMdd"));
+				QString filepath = QString(DATAPATH)+filename;
+				QFile::remove(filepath);
 			}
-			updateSettingsFile(QDate::currentDate().toString("yyyyMMdd"));
 		}
 	}
 }
 
-void DataDownloader::updateSettingsFile(QString maxDataDate, bool updateInd)
+void DataDownloader::updateSettingsFile(QString maxDataDate)
 {
-	// if indicator is false just return as it means nothing to update
-	if ( !updateInd )
-		return;
-
-	QFile::remove(_settingsFile->fileName());
-
+	//qDebug() << "max date updated to = " << maxDataDate << " for channel " << _requestChannel;
 	if(isSingleXMLTVFile())
 	{
+		if ( maxDataDate == "" )
+		{
+			if ( _channelDateMap.find(_requestChannel) == _channelDateMap.end() )
+				maxDataDate = QDate::currentDate().toString("yyyyMMdd");	
+			else
+				return;
+		}
+
+		////////////////////////////////////////////////////
+		//////////// MAIN UPDATE STARTS HERE ///////////////
+		////////////////////////////////////////////////////
+		QFile::remove(_settingsFile->fileName());
+
 		foreach(QString eachChannel, _channelCodeMap.keys())
 		{
-			_channelDateMap[eachChannel].clear();
+			if ( _channelDateMap.find(eachChannel) != _channelDateMap.end() && _channelDateMap[eachChannel].toList().first() > maxDataDate )
+				continue;
+
+			_channelDateMap[eachChannel].clear(); // only need to store max date per channel
 		   _channelDateMap[eachChannel].insert(maxDataDate);
 		}
 	}
-	else
+	else // there is no max date concept, single per day channel files just use request date and store each in the file.
 	{
 		_channelDateMap[_requestChannel].insert(_requestDate.toString("yyyyMMdd"));
 	}
@@ -262,6 +275,21 @@ QStringList DataDownloader::getFilelist()
 	return fullPathFileList;
 }
 
+QDate DataDownloader::getDownloadDate()
+{
+	QDir xmltvPath(QString(DATAPATH), QString("*.xml") );
+	QStringList filelist(xmltvPath.entryList());
+
+	if ( filelist.size() == 0 )
+		return QDate::currentDate().addDays(-5);
+
+	QString filepath = QString(DATAPATH)+filelist.first();
+	QString filedatestr = filepath.section("--",1,1);
+	QDate filedate = QDate::fromString(filedatestr, "yyyyMMdd");
+
+	return filedate;
+}
+
 void DataDownloader::setInput(DownloadInput d)
 {
 	_downloadIndicator = d.downloadIndicator;
