@@ -153,20 +153,15 @@ bool InfoAccess::processXMLTV()
 {
 	// sometimes there is no file generated for a channel so no files will be read, in that 
 	bool filesRead = false;
-	bool updateInd = false;
 	foreach(QString filename, dataDownloader->getFilelist())
 	{
 		filesRead = true;
 		processXMLTV(filename);
 	}
 
-	// update the region settings file with the max data date for the channel
-	// if files are present for a channel and if the file had programme data then
-	// update the setings file with the max date read from the file.
-	if ( filesRead && d->metadata[_currentChannel].maxDate != "00000000" )
-		updateInd = true;
-		
-	dataDownloader->updateSettingsFile(d->metadata[_currentChannel].maxDate, updateInd);
+	// if there are no files or no programmes in the file then maxDate will be ""
+	// for per day channel files this max date is ignored the settings are updated with _requestDate
+	dataDownloader->updateSettingsFile(d->metadata[_currentChannel].maxDate);
 
 	emit finished( true );
 	return true;
@@ -184,7 +179,7 @@ bool InfoAccess::processXMLTV( QString filename )
 	ChannelMetaData metadata;
 	metadata.downloadedDate = QDate::currentDate().toString("yyyyMMdd");
 	metadata.minDate = "99999999";
-	metadata.maxDate = "00000000";
+	metadata.maxDate = "";
 	QString startDate = "UNSET";
 	bool dataPresent = false; // to indicate if any programme data was present
 
@@ -212,6 +207,13 @@ bool InfoAccess::processXMLTV( QString filename )
 			QString tmpStr = (attributes.value("start")).toString();
 			tmpStr.truncate(12);
 			QDateTime datetime = QDateTime::fromString(tmpStr , "yyyyMMddHHmm");
+
+			// sometimes the data is generated in another country so to display time properly we need the 
+			// time zone difference between the regions
+			// example for UK we get data from a belgium site which is 1hr ahead so we need to subtract 1 hr
+			if ( dataDownloader->timeZoneOffset() != 0 )
+				datetime = datetime.addSecs(3600*dataDownloader->timeZoneOffset());
+
 			data.sdate = (datetime.date()).toString();
 			data.stime = datetime.time().toString();
 
@@ -231,6 +233,13 @@ bool InfoAccess::processXMLTV( QString filename )
 			tmpStr = (attributes.value("stop")).toString();
 			tmpStr.truncate(12);
 			datetime = QDateTime::fromString(tmpStr, "yyyyMMddHHmm");
+
+			// sometimes the data is generated in another country so to display time properly we need the 
+			// time zone difference between the regions
+			// example for UK we get data from a belgium site which is 1hr ahead so we need to subtract 1 hr
+			if ( dataDownloader->timeZoneOffset() != 0 )
+				datetime = datetime.addSecs(3600*dataDownloader->timeZoneOffset());
+
 			data.edate = datetime.date().toString();
 			data.etime = datetime.time().toString();
 
@@ -243,20 +252,19 @@ bool InfoAccess::processXMLTV( QString filename )
 				if ( reader.name() == "title" && tokenType == QXmlStreamReader::StartElement )
 				{
 					reader.readNext();
-					data.title = QString::fromUtf8(reader.text().toString().toAscii().constData());
+					data.title = QString::fromUtf8(reader.text().toString().toUtf8().constData());
 				}
 				if ( reader.name() == "desc" && tokenType == QXmlStreamReader::StartElement )
 				{
 					reader.readNext();
-					data.desc = QString::fromUtf8(reader.text().toString().toAscii().constData());
+					data.desc = QString::fromUtf8(reader.text().toString().toUtf8().constData());
 				}
 				if ( reader.name() == "category" && tokenType == QXmlStreamReader::StartElement )
 				{
 					reader.readNext();
-					data.type = QString::fromUtf8(reader.text().toString().toAscii().constData());
+					data.type = QString::fromUtf8(reader.text().toString().toUtf8().constData());
 				}
 	
-	
 				tokenType = reader.readNext();
 			}
 
@@ -319,6 +327,11 @@ void InfoAccess::sendRecordMsg(QStringList input)
 	dataDownloader->sendRecordMsg(input);
 }
 
+QDate InfoAccess::getDownloadDate()
+{
+	    return dataDownloader->getDownloadDate();
+}
+
 void InfoAccess::clear()
 {
 	// clear the previous info
