@@ -21,6 +21,7 @@
 #include <QLineEdit>
 #include <QComboBox>
 #include <QBrush>
+#include <QProgressBar>
 
 #include <mce/mode-names.h>
 #include <mce/dbus-names.h>
@@ -54,9 +55,9 @@ const int ACTION_BUTTON_SIZE = 70;
 int i = 0;
 
 MainWindow::MainWindow()
-    : QMainWindow(), _channelIndex(0), _landscapeOrientation(true), _weeklyMode(false), _dayCount(0)
+    : QMainWindow(), _channelIndex(0), _dayCount(0), _count(0), _landscapeOrientation(true), _searchMode(false), _currentListingMode(false)
 {
-	setWindowTitle("SHOWTIME   ver1.1");
+	setWindowTitle("SHOWTIME   v1.2");
 
 	//////////////////////////////////////////////////////////////////	
 	// this is the class that inits and updates the settings file
@@ -184,6 +185,15 @@ MainWindow::MainWindow()
 	_nextChannelButton->setDisabled(true);
 	_prevChannelButton->setDisabled(true);
 
+	///////////////////////////////////////////////////////////
+	///// a progress bar widget to show animation//////////////
+	_progressLabel = new QLabel("<font color=#00ff00>% of data in memory...</font>");
+	_progress = new QProgressBar(this);
+	_progress->hide();
+	_progressLabel->hide();
+	_progress->setValue(0);
+	///////////////////////////////////////////////////////////
+
 	/////////////////////////////////////////////////////////////////
 	// init the layouts for both orientation modes
 	initLandscape();
@@ -222,8 +232,7 @@ MainWindow::MainWindow()
 	connect(_programmeDetailButton, SIGNAL(clicked()), this, SLOT(showProgrammeDetailWidget()));
 	connect(_recordButton, SIGNAL(clicked()), this, SLOT(showRecordMessage()));
 	connect(_remindButton, SIGNAL(clicked()), this, SLOT(showRemindMessage()));
-	//connect(_searchInput, SIGNAL(activated(QString)), this, SLOT(addSearchString(QString)));
-	//connect(_searchInput->lineEdit(), SIGNAL(editingFinished()), this, SLOT(setCurrentSearchString()));
+	connect(this, SIGNAL(downloadIndex(int)), _progress, SLOT(setValue(int)));
 }
 
 // LOADS THE APP SETTINGS TO MEMORY
@@ -261,7 +270,7 @@ void MainWindow::initListModels()
 
 	QStringList channelList = _infoapi->getChannelList();
 
-	QStandardItem *item = new QStandardItem("YOUR FAVOURITES");
+	QStandardItem *item = new QStandardItem("Favourites");
 	item->setTextAlignment(Qt::AlignCenter); // the Maemo 5 design spec recommends this.
 	item->setEditable(false); // prevent editing of the item
 	_channelListModel->appendRow(item);
@@ -329,26 +338,35 @@ void MainWindow::createMenus()
 	regionAct = new QAction(tr("&REGION"), this);
 	favAct = new QAction(tr("&FAVOURITES"), this);
 	setAct = new QAction(tr("&SETTINGS"), this);
-	modeAct = new QAction(tr("&SWITCH MODE"), this);
-	//openxmlAct = new QAction(tr("&LOAD XMLTV"), this);
+	dailyAct = new QAction(tr("&DAILY MODE"), this);
+	searchAct = new QAction(tr("&SEARCH MODE"), this);
+	currentListingsAct = new QAction(tr("&CURRENT MODE"), this);
+	clearCacheAct = new QAction(tr("&CLEAR CACHE"), this);
 	helpAct = new QAction(tr("&HELP"), this);
+	aboutAct = new QAction(tr("&ABOUT"), this);
 	donateAct = new QAction(tr("&DONATE"), this);
 
 	connect(regionAct, SIGNAL(triggered()), this , SLOT(showRegion()));
 	connect(favAct, SIGNAL(triggered()), this , SLOT(showFavourite()));
 	connect(setAct, SIGNAL(triggered()), this , SLOT(showSettings()));
-	connect(modeAct, SIGNAL(triggered()), this , SLOT(switchMode()));
-	//connect(openxmlAct, SIGNAL(triggered()), this , SLOT(loadXMLTV()));
+	connect(dailyAct, SIGNAL(triggered()), this , SLOT(switchDaily()));
+	connect(searchAct, SIGNAL(triggered()), this , SLOT(switchSearch()));
+	connect(currentListingsAct, SIGNAL(triggered()), this , SLOT(switchCurrentListings()));
+	connect(clearCacheAct, SIGNAL(triggered()), this , SLOT(clearCacheData()));
 	connect(helpAct, SIGNAL(triggered()), this , SLOT(showHelp()));
+	connect(aboutAct, SIGNAL(triggered()), this , SLOT(showAbout()));
 	connect(donateAct, SIGNAL(triggered()), this , SLOT(showDonate()));
 
 	menu = menuBar()->addMenu(tr(""));
 	menu->addAction(regionAct);
 	menu->addAction(favAct);
 	menu->addAction(setAct);
-	menu->addAction(modeAct);
-	//menu->addAction(openxmlAct);
+	menu->addAction(dailyAct);
+	menu->addAction(searchAct);
+	menu->addAction(currentListingsAct);
+	menu->addAction(clearCacheAct);
 	menu->addAction(helpAct);
+	menu->addAction(aboutAct);
 	menu->addAction(donateAct);
 }
 
@@ -368,12 +386,16 @@ void MainWindow::initOrientation()
 	{
 		QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
 							MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
+		QDBusConnection::systemBus().disconnect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+			                MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationChanged(QString)));
 		setLandscape();
 	}
     else if (_settingsWindow->getOrientation() == "PORTRAIT")
 	{
 		QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
 							MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
+		QDBusConnection::systemBus().disconnect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+			                MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationChanged(QString)));
 		setPortrait();
 	}
 }
@@ -391,6 +413,8 @@ void MainWindow::orientationChanged(const QString &newOrientation)
 void MainWindow::showProgrammeListWidgetButtons()
 {
 	_goButton->show();  
+	_recordButton->show();
+	_remindButton->show();
 	_programmeDetail->hide();
 	_programmeDetailLabel->hide();
 	_clearProgButton->hide();
@@ -399,15 +423,19 @@ void MainWindow::showProgrammeListWidgetButtons()
 	_programmeList->show();
 	_channelSelector->show();
 
-	if ( _weeklyMode )
+	if ( _searchMode )
 	{
+		_dateSelector->hide();
 		_searchInput->show();
 		_searchInput->clear();
 		_searchInput->addItems(_settingsWindow->getSearchTitles(_settingsWindow->getRegion(), _currentChannel));
 		_searchInput->lineEdit()->setText(_searchStringPerChannelMap[_currentChannel]);
 	}
 	else
+	{
 		_dateSelector->show();
+		_searchInput->hide();
+	}
 
 	_clearButton->show();
 	_nextChannelButton->show();
@@ -420,10 +448,10 @@ void MainWindow::showProgrammeListWidgetButtons()
 void MainWindow::go()
 {
 	/////////////////////////////////////////////////////////////////
-	// if its weekly download go to the goWeekly, dont do anything else
-	if ( _weeklyMode )
+	// if its weekly download go to the goSearch, dont do anything else
+	if ( _searchMode )
 	{
-		goWeekly();
+		goSearch();
 		return;
 	}
 	/////////////////////////////////////////////////////////////////
@@ -431,41 +459,49 @@ void MainWindow::go()
 	if (_channelSelector->valueText() == "" || _dateSelector->valueText() == "")
 		return;
 
-	//qDebug() << "CHANNEL SELECTED : " << _channelSelector->valueText();
+	/////////////////////////////////////////////////////////
+	// display the progress of the download
+	_progressLabel->show();
+	_progress->show();
+	_progress->setMaximum(_channelsSelected.size());
+	/////////////////////////////////////////////////////////
 
+	/////////////////////////////////////////////////////////////////
+	////if its currentListingMode then fix the date to today/////////
+	/////////and show the buttons for currentListings ///////////////
+	if ( _currentListingMode )
+	{
+		showCurrentListingButtons();
+		_dateSelector->setValueText(QDate::currentDate().toString());
+	}
+	/////////////////////////////////////////////////////////////////
+
+	_channelSelector->setValueText(_channelsSelected[_channelIndex]);
+
+	// set the current date to what is being displayed in the dateselector
 	_currentDate = QDate::fromString(_dateSelector->valueText(), Qt::TextDate);
 
-	// this indicator will be set to false if the requested date > maxDate for the channel
-	bool downloadFresh = true;
-	// the XMLTV files that are single per channel are huge so we dont want to download every time a user requests
-	// a date that is not available already. We download only if the data is 3 days old atleast unless user forces 
-	// us to go forward and download fresh
-	if ( _infoapi->isSingleXMLTVFile() )
-		downloadFresh = isRequestMoreThanMaxDate();
+	// we will use _currentChannel to iterate through the selected channels
+	// channelIndex we will not use as it can be changed by the user using the prev/next buttons
+	// while the read/download of selected channels is going on, hence a different count ( _count)
+	_currentChannel = _channelsSelected[_count];
 
+	// set the input for infoapi
 	DownloadInput d;
 	d.requestDate = QDate::fromString(_dateSelector->valueText(), Qt::TextDate);
 	d.requestChannel = _currentChannel;
 
-	bool dataDownloaded = false;
-
-	// if the indicator to download fresh is not false and the data is not contained locally in the map then download/read from file
-	// so that means you are basically prevented from downloading data if you request a date thats not in the local map
-	// and if that date is higher than the max available data date for the channel
-	if ( downloadFresh && ! _channelDataAvailableMap[_currentChannel].contains(_currentDate.toString("yyyyMMdd")) )
+	// if the data is not contained locally in the map then download/read from file, that means data was already read earlier
+	if ( ! _channelDataAvailableMap[_currentChannel].contains(_currentDate.toString("yyyyMMdd")) )
 	{
 		toggleBusy(true);
-		dataDownloaded = _infoapi->getChannelInfo(d);
+		_infoapi->getChannelInfo(d);
 	}
 	else
 	{
-		//qDebug() << "channel data already in memory";
+		//qDebug() << "channel data already in memory ";
 		finished();
 	}
-
-	// Call the callback slot finished explicitly here as its not called if data isnot downloaded
-	if (!dataDownloaded)
-		finished(false);
 }
 
 // simple message to guide the user to hit the go button when data doesnt exist in local memory
@@ -495,7 +531,7 @@ void MainWindow::selectDate(QString date)
 void MainWindow::selectChannel(QString channel)
 {
 	// IF YOU HAVE SELECTED FAVOURITES SIMPLY LOAD THE FAVOURITES AND RETURN
-	if ( channel == "YOUR FAVOURITES" )
+	if ( channel == "Favourites" )
 	{
 		loadFavourites();
 		return;
@@ -535,6 +571,7 @@ void MainWindow::clearAll()
 	_programmeList->clear();
 	_programmeDetail->clear();
 	_programmeSetForAction.clear();
+	_titleDisplayMap.clear();
 	_nextChannelButton->setDisabled(true);
 	_prevChannelButton->setDisabled(true);
 	_infoapi->clear();
@@ -562,18 +599,36 @@ void MainWindow::finished(bool dataRequested)
 
 	_channelDataAvailableMap[_currentChannel] = _infoapi->metadata()[_currentChannel].availableDates;
 
-	if ( _weeklyMode )
+	// if weekly mode we need to iterate through day1 to day7 of the week so call finishedSearch
+	if ( _searchMode )
 	{
 		// call the weekly download finished to check if we are finished 
-		finishedWeekly();
+		finishedSearch();
 	}
-	else
+	// if it is currentListingMode or the dailyMode just iterate through selected channels 1 by 1
+	else 
 	{
-		toggleBusy(false);
+		//qDebug() << "recvd current listings for " << _channelsSelected[_count] << " channelIndex=" << _count;
+		// if we have finished downloaded the files for the week	
 
-		// we pass the dataRequested here to indicate that we are calling the below method
-		// after requesting data since it wasnt available in the local channelDataMap
-		return showProgrammeListWidget(true);
+		if ( ++_count == _channelsSelected.size() )
+		{
+			_count = 0;
+			_progress->setValue(100);
+			//qDebug() << "all current listings in memory now";
+			toggleBusy(false);
+			_progressLabel->hide();
+			_progress->hide();
+			_progress->setValue(0);
+			// set the current channel back to what is being pointed by the index and whats displayed in the PICK CHANNEL button
+			_currentChannel  = _channelsSelected[_channelIndex];
+			showProgrammeListWidget(true);
+		}
+		else // keep downloading the files
+		{
+			emit downloadIndex(_count);
+			go();
+		}
 	}
 }
 
@@ -583,7 +638,16 @@ void MainWindow::finished(bool dataRequested)
 // and in that case if there is no data we display HitGo
 void MainWindow::showProgrammeListWidget(bool dataRequested)
 {
+
+	// If in current listings mode then just go and display the current listing and return from here
+	if ( _currentListingMode )
+	{
+		showCurrentProgrammeListWidget(dataRequested);
+		return;
+	}
+
 	_programmeList->clear();
+	_titleDisplayMap.clear();
 	_infoLabel->hide();
 	showProgrammeListWidgetButtons();
 	
@@ -619,6 +683,7 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 	foreach(ChannelData data, completeData)
 	{
 		QDateTime progSDateTime = QDateTime::fromString(data.sdate + data.stime, "ddd MMM d yyyyHH:mm:ss");
+		QDateTime progEDateTime = QDateTime::fromString(data.edate + data.etime, "ddd MMM d yyyyHH:mm:ss");
 		QString title = data.title;
 		QString sdate = data.sdate;
 		QString stime = data.stime;
@@ -626,40 +691,39 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 		QString etime = data.etime;
 		etime.truncate(5);
 		QString time = stime + " - " + etime;
+
 		// have 2 keys here as in the display we dont want to display date
 		// but on clicking the item in the list we want the key to have the date also just in case the user selects the same program 
 		// for multiple days
 		QString keyForDisplay;
 		QString keyForInsert;
+		keyForInsert = title + sdate + time;
+		breakTitle(title);
 		if ( _landscapeOrientation )
 		{
-			if ( _weeklyMode ) // less tabs for weekly as we have date also
+			if ( _searchMode ) // less tabs for weekly as we have date also
 			{
 				keyForDisplay = title + "\n\t\t\t\t" + sdate + " : " + time;
-				keyForInsert = title + "\n\t\t\t\t" + sdate + " : " + time;
 			}
 			else
 			{
 				keyForDisplay = title + "\n\t\t\t\t\t\t" + time;
-				keyForInsert = title + " " + time + " " + data.sdate;
 			}
 		}
 		else // in portrait mode we need less tabs to prevent horizontal scrolling
 		{
-			if ( _weeklyMode ) // less tabs for weekly as we have date also
+			if ( _searchMode ) // less tabs for weekly as we have date also
 			{
 				keyForDisplay = title + "\n" + sdate + " : " + time;
-				keyForInsert = title + "\n" + sdate + " : " + time;
 			}
 			else
 			{
 				keyForDisplay = title + "\n\t\t\t" + time;
-				keyForInsert = title + " " + time + " " + data.sdate;
 			}
 		}
 
 		// see if title matches the search string in weekly search mode
-		if ( _weeklyMode )
+		if ( _searchMode )
 		{
 			titleMatched = false;
 
@@ -679,9 +743,9 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 		}
 
 		// if its weekly mode then check if title matches else check if programme start date matches the user chosen date
-		if ( (!_weeklyMode && data.sdate == _currentDate.toString(Qt::TextDate)) || (_weeklyMode && titleMatched) )
+		if ( (!_searchMode && data.sdate == _currentDate.toString(Qt::TextDate)) || (_searchMode && titleMatched) )
 		{
-			if ( hidePastListings && progSDateTime < QDateTime::currentDateTime() )
+			if ( hidePastListings && progSDateTime < QDateTime::currentDateTime() && progEDateTime <= QDateTime::currentDateTime())
 			{
 				continue;
 			}
@@ -691,25 +755,24 @@ void MainWindow::showProgrammeListWidget(bool dataRequested)
 				continue;
 			}
 		
+			_titleDisplayMap[keyForDisplay]=keyForInsert;
+
 			QListWidgetItem *item = new QListWidgetItem(keyForDisplay, _programmeList);	
 			QBrush brush(Qt::cyan);
 			if ( (i++ % 2 ) ) item->setForeground(brush);
 			_programmeList->addItem(item);
+			// if its a selected programme put a tick next to it
+			if ( _programmeSetForAction.find(keyForInsert) != _programmeSetForAction.end() )
+				item->setIcon(QIcon(_settingsWindow->getIconPath() + "tick.png"));
 			_channelDataMap[keyForInsert] = data;
 			dataAvailable = true;
 		}
 	}
-	// this means that data is not available locally in channelDataMap and also it hasnt been
-	// requested so it means you have to hit GO :-) !
-	if ( !dataRequested && !dataAvailable )
+	// this means that data is not available locally in channelDataMap 
+	if ( !dataAvailable )
 	{
-		if ( _weeklyMode )	showInfoLabel( QString("<b>HIT SEARCH !<\b>\n") + QString("\n\n*Note data may be unavailable for some channels for some/all dates") );
-		else 				showInfoLabel( QString("<b>HIT GO !<\b>\n") + QString("\n\n*Note data may be unavailable for some channels for some/all dates") );
-	}
-	else if ( dataRequested && !dataAvailable )
-	{
-		if ( _weeklyMode )	showInfoLabel( QString("Sorry, requested programme title does not exist in the available data for the channel.\nSwitch Modes and click GO to check the dates for which data is available(marked in green), you could try refreshing your data in case its old.") );
-		else				showInfoLabel( QString("<b>NO DATA AVAILABLE FOR THIS CHANNEL !<\b>") );
+		if ( _searchMode )	showInfoLabel( QString("Have you clicked on Search already ? If yes then\nRequested programme title does not exist in the available data for the channel.\nIn case the data is old you could clear the data cache from the menu and try again.") );
+		else				showInfoLabel( QString("Have you clicked on GO already ? If yes then\nNo data available for this channel !\nIn case the data is old you could clear the data cache from the menu and try again.") );
 	}
 
 }
@@ -809,18 +872,7 @@ void MainWindow::showNextPrevChannelButtons()
 // action list is used when applying action ( remind/record )
 void MainWindow::addProgrammeActionList(QListWidgetItem* programme)
 {
-	QString key;
-	// IF its weekly search mode then the key is what is shown on the listwidget
-	// ELSE if its daily mode we dont show the date so that needs to be appended to the key
-	if ( _weeklyMode )
-	{
-		key = programme->text();
-	}
-	// add the date to the listwidgetitem as in the list we dont display the date
-	else if ( _dateSelector->valueText() != "" )
-	{
-		key = (programme->text() + "\t" + _dateSelector->valueText()).simplified();
-	}
+	QString key = _titleDisplayMap[programme->text()];
 
 	// on clicking this slot is called so
 	// if the program exists then remove it ( as user deselected) else add it(user selected)
@@ -828,11 +880,14 @@ void MainWindow::addProgrammeActionList(QListWidgetItem* programme)
 	{
 		//qDebug() << "Selecting " << key;
 		_programmeSetForAction.insert(key);
+		// if its a selected programme put a tick next to it
+		programme->setIcon(QIcon(_settingsWindow->getIconPath() + "tick.png"));
 	}
 	else
 	{
 		//qDebug() << "De Selecting " << key;
 		_programmeSetForAction.remove(key);
+		programme->setIcon(QIcon());
 	}
 }
 
@@ -842,7 +897,7 @@ void MainWindow::showRecordMessage()
 {
     if ( _settingsWindow->getRegion() != "UK" )
     {
-		QMaemo5InformationBox::information(this, "<font color=#000000>SORRY THIS FUNCTIONALITY IS ONLY SUPPORTED BY UK AT THE MOMENT, if you are aware of any support for your region, please let me know either in my thread talk.maemo or send me an email</font>" , QMaemo5InformationBox::DefaultTimeout);
+		QMaemo5InformationBox::information(this, "<font color=#000000>Sorry this functionality is only supported by UK at the moment, if you are aware of any support for your region, please let me know either in my thread talk.maemo or send me an email</font>" , QMaemo5InformationBox::DefaultTimeout);
 
         return;
     }
@@ -900,7 +955,7 @@ void MainWindow::showRemindMessage()
 	}
 
 	if(_programmeSetForAction.count() != 0)
-		QMaemo5InformationBox::information(this, "<font color=#000000><b>YOUR SHOWTIME CALENDAR HAS BEEN UPDATED WITH YOUR SELECTED PROGRAMMES</b></font>" , QMaemo5InformationBox::DefaultTimeout);
+		QMaemo5InformationBox::information(this, "<font color=#000000><b>Your SHOWTIME calendar has been updated with your selected programmes</b></font>" , QMaemo5InformationBox::DefaultTimeout);
 
 	clearProg();  // clear selected programmes
 }
@@ -964,6 +1019,8 @@ void MainWindow::initLandscape()
 	_lv1layout->addLayout(_lh1layout);
 	_lv1layout->addWidget(_programmeDetail);
 	_lv1layout->addWidget(_programmeList);
+	_lv1layout->addWidget(_progressLabel);
+	_lv1layout->addWidget(_progress);
 	_lv1layout->addWidget(_infoLabel);
 
 	// define the main layout	
@@ -999,8 +1056,8 @@ void MainWindow::initPortrait()
 	_ph2layout->addWidget(_clearProgButton); // this is available in programme detail mode only
 	_ph2layout->addWidget(_backToProgrammeListButton);// this is available in programme detail mode only
 
+
 	// define the data panel layout	
-	_ph3layout->addWidget(_infoLabel);
 	_ph3layout->addWidget(_programmeDetail);// this is available in programme detail mode only
 	_ph3layout->addWidget(_programmeList);
 
@@ -1014,6 +1071,9 @@ void MainWindow::initPortrait()
 	_pv1layout->addLayout(_ph1layout);
 	_pv1layout->addLayout(_ph2layout);
 	_pv1layout->addLayout(_ph3layout);
+	_pv1layout->addWidget(_progressLabel);
+	_pv1layout->addWidget(_progress);
+	_pv1layout->addWidget(_infoLabel);
 	_pv1layout->addLayout(_ph4layout);
 
 	// define the main layout	
@@ -1027,12 +1087,16 @@ MainWindow::~MainWindow()
 {
 }
 
-// slot to load your own xmltv file
-void MainWindow::loadXMLTV()
+// slot to show info about showtime
+void MainWindow::showAbout()
 {
-	//disableAllWidgets();
-	QString filename(_settingsWindow->getBinPath() + "xmltvfile.xml");
-	_infoapi->processXMLTV(filename);
+	QString about = QString("<font color=#0000ff>A global TV channel list viewer with calendar reminder integration. </font>") +
+ "This app downloads xmltv data depending on the region selected and displays " +
+ "the tv channel listings , in most cases for an entire week. The user can then " +
+ "view details of the programme and select them to be added to the N900 calendar.";
+
+	QString title = QString("SHOWTIME v1.2");
+	QMessageBox::about(this, title, about);
 }
 
 // slot to encourage me more ;-)
@@ -1077,29 +1141,39 @@ void MainWindow::showSettings()
 }
 
 // slot to search for the title string in the selected channel for the week
-void MainWindow::switchMode()
+void MainWindow::switchDaily()
 {
-	//clearAll();
-
-	if ( _weeklyMode )
-	{
-		_dateSelector->show();
-		_searchInput->hide();
-		_weeklyMode = false;
+	_programmeList->clear();
+	clearProg(); // keys are different in different modes
+	_searchMode = false;
+	_currentListingMode = false;
+	showProgrammeListWidget();
 	
-		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
-	}
-	else
-	{
-		_dateSelector->hide();
-		_searchInput->show();
-		_weeklyMode = true;
-		_searchInput->clear();
-		_searchInput->addItems(_settingsWindow->getSearchTitles(_settingsWindow->getRegion(), _currentChannel));
-		_searchInput->lineEdit()->setText(_searchStringPerChannelMap[_currentChannel]);
+	_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
+}
 
-		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "search.png"));
-	}
+void MainWindow::switchSearch()
+{
+	_programmeList->clear();
+	clearProg(); // keys are different in different modes
+	_searchMode = true;
+	_currentListingMode = false;
+	showProgrammeListWidget();
+
+	_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "search.png"));
+}
+
+void MainWindow::switchCurrentListings()
+{
+	showCurrentListingButtons();
+	_programmeList->clear();
+	clearProg(); // keys are different in different modes
+	_searchMode = false;
+	_currentListingMode = true;
+	if ( _channelsSelected.size() == 0 )
+		QMaemo5InformationBox::information(this, "<font color=#000000>Go back to Daily Mode and select some channels to see the current listings.</font>" 
+																												, QMaemo5InformationBox::DefaultTimeout);
+	go();
 }
 
 // SLOT::reloads the favourite settings
@@ -1143,7 +1217,7 @@ void MainWindow::reInitMiscSettings()
 	_remindButton->setIcon(QIcon(_settingsWindow->getIconPath() + "remind.png"));
 	_backToProgrammeListButton->setIcon(QIcon(_settingsWindow->getIconPath() + "back.png"));
 	_clearProgButton->setIcon(QIcon(_settingsWindow->getIconPath() + "clear.png"));
-	if ( _weeklyMode )
+	if ( _searchMode )
 		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "search.png"));
 	else
 		_goButton->setIcon(QIcon(_settingsWindow->getIconPath() + "go.png"));
@@ -1207,38 +1281,34 @@ void MainWindow::showHelp()
 	_helpWindow->show();
 }
 
-bool MainWindow::isRequestMoreThanMaxDate()
+void MainWindow::clearCacheData()
 {
 	bool result = true;
-    QStringList keylist = _infoapi->metadata().keys();
-	if ( keylist.contains(_currentChannel) )
-	{
-    	ChannelMetaData metadata = _infoapi->metadata()[_currentChannel];
-		QDate downloadedDate = QDate::fromString(metadata.downloadedDate, "yyyyMMdd");
-		QDate maxDate = QDate::fromString(metadata.maxDate, "yyyyMMdd");
-	
-		if ( _currentDate > maxDate )
-		{
-			if ( downloadedDate.daysTo(QDate::currentDate()) < 3 )
-			{
-				QMessageBox::StandardButton ret;
-				QString question = "The data you have is only " + QString::number(downloadedDate.daysTo(QDate::currentDate())) + " days old.\n" +
-								"Maybe you should wait till its atleast 3 days old so the chances that the source has the data is higher.\n" +
-								"If you still wish to proceed click YES else click NO to use available data";
-				ret = QMessageBox::question(this, tr("Early Download Warning !"), question ,QMessageBox::Yes | QMessageBox::No);
-				if (ret == QMessageBox::Yes)
-					result = true;
-				else if (ret == QMessageBox::No)
-					result = false;
-			}
-			else
-			{
-				result = true; // if its more than 3 days old no need to ask the user just download :-)
-			}
-		}
+	QDate downloadedDate = _infoapi->getDownloadDate();
 
+	if ( downloadedDate.daysTo(QDate::currentDate()) < 3 )
+	{
+		QMessageBox::StandardButton ret;
+		QString question = QString("You are about to clear your data cache and memory completely and start all fresh again.\n") +
+						"The data cache you have is only " + QString::number(downloadedDate.daysTo(QDate::currentDate())) + " day(s) old.\n" +
+						"Maybe you should wait till its atleast 3 days old so the chances that the source has the data is higher.\n" +
+						"If you still wish to proceed click YES else click NO to use available data";
+		ret = QMessageBox::question(this, tr("Early Download Warning !"), question ,QMessageBox::Yes | QMessageBox::No);
+		if (ret == QMessageBox::Yes)
+			result = true;
+		else if (ret == QMessageBox::No)
+			result = false;
+	}
+	else
+	{
+		result = true; // if its more than 3 days old no need to ask the user just download :-)
+	}
+
+	if ( result )
+	{
+		_infoapi->clearRegionData();
+		clearAll();
 	}
-	return result;
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1247,12 +1317,12 @@ bool MainWindow::isRequestMoreThanMaxDate()
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // The method that calls the infoaccess class to download/read xmltv weekly data and calls the search function
-void MainWindow::goWeekly(QDate date)
+void MainWindow::goSearch(QDate date)
 {
 	if (_channelSelector->valueText() == "" || _searchInput->currentText() == "")
 		return;
 
-	//qDebug() << "In GoWeekly : " << _channelSelector->valueText() << " " << date;
+	//qDebug() << "In GoSearch : " << _channelSelector->valueText() << " " << date;
 
 	// store the current search string for the channel so when you press the arrow keys your
 	// search is also remembered :-)	
@@ -1286,7 +1356,7 @@ void MainWindow::goWeekly(QDate date)
 }
 
 // called from a callback (finished) when the XMLTV info required is downloaded/read
-void MainWindow::finishedWeekly()
+void MainWindow::finishedSearch()
 {
 	_infoLabel->hide();
 
@@ -1300,7 +1370,7 @@ void MainWindow::finishedWeekly()
 	else // keep downloading the files
 	{
 		++_dayCount;
-		goWeekly(QDate::currentDate().addDays(_dayCount));
+		goSearch(QDate::currentDate().addDays(_dayCount));
 	}
 
 	return;
@@ -1323,5 +1393,141 @@ void MainWindow::setCurrentSearchString()
 	_currentSearchString = _searchInput->currentText();
 }
 
+////////////////////////////////////////////////////////////////////////////////////////////////////////////
+//
+///////////////////////////////// CURRENT LISTINGS CHANGES after version 1.1-4 /////////////////////////////
+
+void MainWindow::showCurrentListingButtons()
+{
+	_searchInput->hide();
+	_dateSelector->hide();
+	_recordButton->hide();
+	_remindButton->hide();
+	_channelSelector->hide();
+	_goButton->hide();
+	_prevChannelButton->hide();
+	_nextChannelButton->hide();
+	_programmeDetail->hide();
+	_programmeDetailLabel->hide();
+	_clearProgButton->hide();
+	_backToProgrammeListButton->hide();
+	_programmeList->show();
+	_clearButton->show();	
+	_programmeDetailButton->show();
+}
+
+void MainWindow::finishedCurrent()
+{
+	_infoLabel->hide();
+
+	//qDebug() << "recvd current listings for " << _channelsSelected[_channelIndex] << " channelIndex=" << _channelIndex;
+	// if we have finished downloaded the files for the week	
+
+	if ( _channelIndex-- == 0 )
+	{
+		_channelIndex = 0;
+		//qDebug() << "all current listings in memory now";
+		toggleBusy(false);
+		_progressLabel->hide();
+		_progress->hide();
+		showProgrammeListWidget(true);
+	}
+	else // keep downloading the files
+	{
+		emit downloadIndex(_channelsSelected.size() - _channelIndex);
+
+		_channelSelector->setValueText(_channelsSelected[_channelIndex]);
+		go();
+	}
+
+	return;
+}
+
+void MainWindow::showCurrentProgrammeListWidget(bool dataRequested)
+{
+	_programmeList->clear();
+	_titleDisplayMap.clear();
+	_infoLabel->hide();
+
+	showCurrentListingButtons();
+
+	// store the data in memory for all the favourite channels
+   	QList<ChannelData> completeData;
+	foreach(QString channel , _channelsSelected)
+		completeData.append( (_infoapi->results())[channel] );
+
+	bool dataAvailable = false;
+
+	foreach(ChannelData data, completeData)
+	{
+		QDateTime progSDateTime = QDateTime::fromString(data.sdate + data.stime, "ddd MMM d yyyyHH:mm:ss");
+		QDateTime progEDateTime = QDateTime::fromString(data.edate + data.etime, "ddd MMM d yyyyHH:mm:ss");
+		QString title = data.title;
+		QString sdate = data.sdate;
+		QString stime = data.stime;
+		stime.truncate(5);
+		QString etime = data.etime;
+		etime.truncate(5);
+		QString time = stime + " - " + etime;
+		QString channelname = data.channelId;
+
+		QString keyForInsert = title + sdate + time;
+		breakTitle(title);
+		QString displayLine;
+		if ( _landscapeOrientation )
+		{
+			displayLine = title + "\n\t\t\t\t\t\t" + time;
+		}
+		else
+		{
+			displayLine = title + "\n\t\t\t" + time;
+		}
+
+		// if th programme is today and started 1hour ago and is still on 
+		// and the programme start time is in the next 1 hour
+		// and the programme end time is greater than current time then show the programme as its currently ON.
+		if ( data.sdate == QDate::currentDate().toString(Qt::TextDate) && 
+			progSDateTime > QDateTime::currentDateTime().addSecs(-3601) && progSDateTime < QDateTime::currentDateTime().addSecs(3601) && 
+			progEDateTime > QDateTime::currentDateTime())
+		{
+			_titleDisplayMap[displayLine]=keyForInsert;
+
+			QListWidgetItem *item = new QListWidgetItem(displayLine, _programmeList);	
+			QBrush brush(Qt::cyan);
+			if ( (i++ % 2 ) ) item->setForeground(brush);
+			_programmeList->addItem(item);
+			// if its a selected programme put a tick next to it
+			if ( _programmeSetForAction.find(keyForInsert) != _programmeSetForAction.end() )
+				item->setIcon(QIcon(_settingsWindow->getIconPath() + "tick.png"));
+			_channelDataMap[keyForInsert] = data;
+			dataAvailable = true;
+		}
+	}
+	// this means that data is not available locally in channelDataMap and also it hasnt been
+	// requested so it means you have to hit GO :-) !
+	if ( !dataAvailable )
+	{
+		showInfoLabel( QString("No data available for this channel !\nYou could try to clear the Data Cache from the menu if its old and try again") );
+	}
+
+}
+
+void MainWindow::breakTitle(QString& title)
+{
+	int position;
+	if ( _landscapeOrientation )
+		position = 50;
+	else
+		position = 40;
+
+	// break the huge title in order to prevent horizontal scrolling that makes scrolling slow and difficult
+	if ( title.length() > position )
+	{
+		QString s1 =  title.left(position);
+		QString s2 =  title.right(title.length() - position);
+		title = s1 + "\n" + s2;
+	}
+}
+
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////############## END OF SHOWTIM ###############////////////////////////////////////////////////
