@@ -5,6 +5,7 @@
 #include "misc.h"
 
 class QLabel;
+class QMaemo5ValueButton;
 
 class MiscSettingsWindow : public SettingsWindow 
 {
@@ -27,9 +28,14 @@ private slots:
 	void setAuto();
 	void setEventOnly();
 	void setEventAndAlarm();
+	void setShowPast();
+	void setHidePast();
+	void setStartPrimeTime();
+	void setEndPrimeTime();
 	void setIconSet1();
 	void setIconSet2();
 	void setIconSet3();
+	void setIconSet4();
 	void setIconSet(QString iconset);
 	void cancel();
 	void save();
@@ -41,6 +47,9 @@ private:
 	QLabel* preview1;
 	QLabel* preview2;
 	QLabel* preview3;
+	QLabel* preview4;
+	QMaemo5ValueButton* startTimeSelector;
+	QMaemo5ValueButton* endTimeSelector;
 };
 
 #endif // MISCSETTINGSWINDOW_H
