@@ -24,16 +24,25 @@ public:
 	QString getIconType();
 	const QStringList getFavourites(QString region) const;
 	QStringList getFavourites(QString region);
+	QStringList getSearchTitles(QString region, QString channel);
+	QString getShowPastInd();
+	QString getPrimeTimeStart();
+	QString getPrimeTimeEnd();
 	const QString getIconPath();
 	const QString getBinPath();
 	QMap<QString, QStringList>& getSettingsMap();
 	void removeFromFavourite(QString region, QString channel);
+	void removeFromSearchTitles(QString region, QString channel, QString searchTitle);
 
 	void setRegion(QString region);
 	void setRemindType(QString remindType);
 	void setOrientation(QString orientation);
 	void setIconType(QString iconset);
 	void setFavourites(QString region, QString channel);
+	void setSearchTitles(QString region, QString channel, QString searchTitle);
+	void setShowPastInd(QString indicator);
+	void setPrimeTimeStart(QString time);
+	void setPrimeTimeEnd(QString time);
 
 	void loadSettings();
 	void updateSettings();
@@ -45,7 +54,7 @@ private slots:
 protected: // functions
 
 protected:
-	QMap<QString, QStringList> _settingsMap;
+	static QMap<QString, QStringList> _settingsMap;
 
 private:
 	const char* BINPATH;
